@@ -4,7 +4,7 @@ use Carp qw(croak confess);
 use Mojo::URL;
 use Mojo::Home;
 use Mojo::IOLoop;
-use List::MoreUtils qw(none);
+use List::Util qw(none);
 use File::Basename 'dirname';
 use File::ShareDir qw(dist_file);
 
@@ -16,7 +16,7 @@ use Mojo::RabbitMQ::Client::Consumer;
 use Mojo::RabbitMQ::Client::LocalQueue;
 use Mojo::RabbitMQ::Client::Publisher;
 
-our $VERSION = "0.0.7";
+our $VERSION = "0.0.8";
 
 use constant DEBUG => $ENV{MOJO_RABBITMQ_DEBUG} // 0;
 
@@ -454,6 +454,7 @@ sub _write {
   my $id    = shift @_;
   my $frame = shift @_;
 
+  utf8::downgrade($frame);
   $self->_loop->stream($id)->write($frame)
     if defined $self->_loop->stream($id);
 }
